==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServiceEntryListFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ServiceEntryListFluentImpl<A extends ServiceEntryListFluent<A>> extends BaseFluent<A> implements ServiceEntryListFluent<A>{

    private String apiVersion;
    private List<ServiceEntryBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ServiceEntryListFluentImpl(){
    }
    public ServiceEntryListFluentImpl(ServiceEntryList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A addToItems(int index,ServiceEntry item){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,ServiceEntry item){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            ServiceEntryBuilder builder = new ServiceEntryBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(ServiceEntry... items){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<ServiceEntry> items){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(ServiceEntry... items){
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<ServiceEntry> items){
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceEntry> getItems(){
            return build(items);
    }

    public List<ServiceEntry> buildItems(){
            return build(items);
    }

    public ServiceEntry buildItem(int index){
            return this.items.get(index).build();
    }

    public ServiceEntry buildFirstItem(){
            return this.items.get(0).build();
    }

    public ServiceEntry buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public ServiceEntry buildMatchingItem(Predicate<ServiceEntryBuilder> predicate){
            for (ServiceEntryBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withItems(List<ServiceEntry> items){
            if (this.items != null) { _visitables.removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<ServiceEntryBuilder>(); for (ServiceEntry item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(ServiceEntry... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (ServiceEntry item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ServiceEntryListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ServiceEntryListFluent.ItemsNested<A> addNewItemLike(ServiceEntry item){
            return new ItemsNestedImpl(-1, item);
    }

    public ServiceEntryListFluent.ItemsNested<A> setNewItemLike(int index,ServiceEntry item){
            return new ItemsNestedImpl(index, item);
    }

    public ServiceEntryListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ServiceEntryListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ServiceEntryListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ServiceEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceEntryBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ServiceEntryListFluentImpl that = (ServiceEntryListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends ServiceEntryFluentImpl<ServiceEntryListFluent.ItemsNested<N>> implements ServiceEntryListFluent.ItemsNested<N>,Nested<N>{

            private final ServiceEntryBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,ServiceEntry item){
                    this.index = index;
                    this.builder = new ServiceEntryBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new ServiceEntryBuilder(this);
            }
    
    public N and(){
            return (N) ServiceEntryListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServiceEntryListFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class ServiceEntryListFluentImpl<A extends ServiceEntryListFluent<A>> extends BaseFluent<A> implements ServiceEntryListFluent<A>{

    private String apiVersion;
    private List<ServiceEntryBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ServiceEntryListFluentImpl(){
    }
    public ServiceEntryListFluentImpl(ServiceEntryList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,ServiceEntry item){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,ServiceEntry item){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            ServiceEntryBuilder builder = new ServiceEntryBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(ServiceEntry... items){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<ServiceEntry> items){
            if (this.items == null) {this.items = new ArrayList<ServiceEntryBuilder>();}
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(ServiceEntry... items){
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<ServiceEntry> items){
            for (ServiceEntry item : items) {ServiceEntryBuilder builder = new ServiceEntryBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<ServiceEntryBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<ServiceEntryBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              ServiceEntryBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceEntry> getItems(){
            return build(items);
    }

    public List<ServiceEntry> buildItems(){
            return build(items);
    }

    public ServiceEntry buildItem(int index){
            return this.items.get(index).build();
    }

    public ServiceEntry buildFirstItem(){
            return this.items.get(0).build();
    }

    public ServiceEntry buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public ServiceEntry buildMatchingItem(Predicate<ServiceEntryBuilder> predicate){
            for (ServiceEntryBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<ServiceEntryBuilder> predicate){
            for (ServiceEntryBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<ServiceEntry> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<ServiceEntryBuilder>(); for (ServiceEntry item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(ServiceEntry... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (ServiceEntry item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ServiceEntryListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ServiceEntryListFluent.ItemsNested<A> addNewItemLike(ServiceEntry item){
            return new ItemsNestedImpl(-1, item);
    }

    public ServiceEntryListFluent.ItemsNested<A> setNewItemLike(int index,ServiceEntry item){
            return new ItemsNestedImpl(index, item);
    }

    public ServiceEntryListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ServiceEntryListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ServiceEntryListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ServiceEntryListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceEntryBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ServiceEntryListFluentImpl that = (ServiceEntryListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends ServiceEntryFluentImpl<ServiceEntryListFluent.ItemsNested<N>> implements ServiceEntryListFluent.ItemsNested<N>,Nested<N>{

            private final ServiceEntryBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,ServiceEntry item){
                    this.index = index;
                    this.builder = new ServiceEntryBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new ServiceEntryBuilder(this);
            }
    
    public N and(){
            return (N) ServiceEntryListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
